@@ -68,10 +68,6 @@ def get_internal_wsgi_application():
     return app
 
 
-class WSGIServerException(Exception):
-    pass
-
-
 class ServerHandler(simple_server.ServerHandler, object):
     error_status = str("500 INTERNAL SERVER ERROR")
 
@@ -132,10 +128,7 @@ class WSGIServer(simple_server.WSGIServer, object):
 
     def server_bind(self):
         """Override server_bind to store the server name."""
-        try:
-            super(WSGIServer, self).server_bind()
-        except Exception as e:
-            raise WSGIServerException(e)
+        super(WSGIServer, self).server_bind()
         self.setup_environ()
 
 
@@ -191,6 +184,7 @@ def run(addr, port, wsgi_handler, ipv6=False, threading=False):
         httpd_cls = WSGIServer
     httpd = httpd_cls(server_address, WSGIRequestHandler, ipv6=ipv6)
     httpd.set_app(wsgi_handler)
+    
     try:
         httpd.serve_forever()
     except select.error as (errno, msg):
